@@ -57,6 +57,7 @@ static const gchar *author_credits[] = {
   "Peter Astrand  <astrand lysator liu se>",
   "Jonathan Blandford  <jrb redhat com>",
   "Paul Bolle  <pebolle tiscali nl>",
+  "Paolo Borelli  <pborelli katamail com>",
   "Leonardo Boshell  <p kapcoweb com>",
   "Ross Burton  <ross burtonini com>",
   "Damien Carbery  <damien carbery sun com>",
@@ -66,7 +67,8 @@ static const gchar *author_credits[] = {
   "John Fleck  <jfleck inkstain net>",
   "Sebastian Heinlein <glatzor pimpzkru de>",
   "James Henstridge  <james daa com au>",
-  "Mihai T  Lazarescu  <mihai email it>",
+  "Chris Lahey  <clahey ximian com>",
+  "Mihai T Lazarescu  <mihai email it>",
   "Sebastian Kapfer <sebastian_kapfer web de>",
   "Tomasz Koczko  <kloczek pld org pl>",
   "Jordi Mallach  <jordi sindominio net>",
@@ -166,6 +168,13 @@ static const gchar *author_credits[] = {
   "Daniel Yacob  <locales geez org>",
   "Funda Wang <fundawang linux net cn>",
   "Alexander Winston  <alexander winston comcast net>",
+  "Adam Weinberger <adamw gnome org>",
+  "Josep Puigdemont <josep imatge-sintetica com>",
+  "Adi Attar <aattar cvs gnome org>",
+  "Steve Murphy <murf e-tools com>",
+  "Abduxukur Abdurixit <abduxukur.abdurixit t-systems ch>",
+  "Ignacio Casal Quinteiro <nacho.resa gmail com>",
+  "Vladimir Petkov <vpetkov i-space org>",
   NULL
 };
 
